@@ -2,13 +2,23 @@ from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.services.jwt.jwtPayload import JWTPayload
 from nerualpha.request.IRequestParams import IRequestParams
+from nerualpha.services.config.IUrlObject import IUrlObject
+from nerualpha.services.config.pathObject import PathObject
 
 
 #interface
 class IBridge(ABC):
     @abstractmethod
+    def parsePath(self,path):
+        pass
+    @abstractmethod
+    def parseUrl(self,url):
+        pass
+    @abstractmethod
+    def testRegEx(self,str,regExp):
+        pass
+    @abstractmethod
     def isInteger(self,value):
         pass
     @abstractmethod
@@ -45,7 +55,7 @@ class IBridge(ABC):
     def toISOString(self,seconds):
         pass
     @abstractmethod
-    def jwtSign(self,payload,privateKey,algorithm):
+    def jwtSign(self,payload,privateKey,alg,options = None):
         pass
     @abstractmethod
     def jwtVerify(self,token,privateKey,algorithm):
