@@ -17,6 +17,9 @@ from nerualpha.providers.assets.contracts.linkPayload import LinkPayload
 from nerualpha.services.config.urlObject import UrlObject
 from nerualpha.providers.assets.contracts.assetLinkResponse import AssetLinkResponse
 from nerualpha.providers.assets.contracts.assetListResponse import AssetListResponse
+from nerualpha.request.formDataObject import FormDataObject
+from nerualpha.request.IFormDataObject import IFormDataObject
+from nerualpha.request.responseTypes import ResponseTypes
 
 @dataclass
 class Assets(IAssets):
@@ -52,6 +55,7 @@ class Assets(IAssets):
         url.query["key"] = remoteFilePath
         requestParams.url = url
         requestParams.headers = self.session.constructRequestHeaders()
+        requestParams.responseType = ResponseTypes.STREAM
         return RequestInterfaceWithParams(self.session,requestParams)
     
     def generateLink(self,remoteFilePath,duration = "5m"):
@@ -63,14 +67,26 @@ class Assets(IAssets):
         return RequestInterfaceWithParams(self.session,requestParams)
     
     def uploadFiles(self,localFilePaths,remoteDir):
+        streams = []
+        for i in range(0,localFilePaths.__len__()):
+            streams.append(self.bridge.createReadStream(localFilePaths[i]))
+        
+        return self.uploadData(streams,remoteDir)
+    
+    def uploadData(self,data,remoteDir,filenames = None):
+        url = self.config.getExecutionUrl(self.provider,AssetsActions.Copy)
         requestParams = RequestParams()
         requestParams.method = RequestMethods.POST
-        data = {}
-        for i in range(0,localFilePaths.__len__()):
-            data[f'files[{i}]'] = self.bridge.createReadStream(localFilePaths[i])
+        requestParams.data = []
+        for i in range(0,data.__len__()):
+            formData = FormDataObject()
+            formData.name = f'file[{i}]'
+            formData.value = data[i]
+            if filenames is not None and filenames[i] is not None:
+                formData.filename = filenames[i]
+            
+            requestParams.data.append(formData)
         
-        requestParams.data = data
-        url = self.config.getExecutionUrl(self.provider,AssetsActions.Copy)
         url.query["dst"] = remoteDir
         requestParams.url = url
         requestParams.headers = self.session.constructRequestHeaders()
