@@ -11,6 +11,7 @@ from nerualpha.providers.state.stateCommand import StateCommand
 from nerualpha.providers.state.stateOperations import StateOperations
 from nerualpha.request.requestMethods import RequestMethods
 from nerualpha.services.config.urlObject import UrlObject
+from nerualpha.providers.state.expireOptions import ExpireOptions
 
 @dataclass
 class State(IState):
@@ -48,7 +49,10 @@ class State(IState):
         payload = []
         command = self.createCommand(StateOperations.GET,key,payload)
         result = await self.executeCommand(command)
-        return self.bridge.jsonParse(result)
+        if result is not None and result != "":
+            return self.bridge.jsonParse(result)
+        
+        return None
     
     async def delete(self,key):
         payload = []
@@ -110,6 +114,21 @@ class State(IState):
         command = self.createCommand(StateOperations.HSET,htable,payload)
         return await self.executeCommand(command)
     
+    async def hincrby(self,htable,key,increment):
+        payload = [key,self.bridge.jsonStringify(increment)]
+        command = self.createCommand(StateOperations.HINCRBY,htable,payload)
+        return await self.executeCommand(command)
+    
+    async def hlen(self,htable):
+        payload = []
+        command = self.createCommand(StateOperations.HLEN,htable,payload)
+        return await self.executeCommand(command)
+    
+    async def hscan(self,htable,cursor,pattern,count):
+        payload = [cursor,"MATCH",pattern,"COUNT",self.bridge.jsonStringify(count)]
+        command = self.createCommand(StateOperations.HSCAN,htable,payload)
+        return await self.executeCommand(command)
+    
     async def rpush(self,list,value):
         payload = [self.bridge.jsonStringify(value)]
         command = self.createCommand(StateOperations.RPUSH,list,payload)
@@ -155,7 +174,7 @@ class State(IState):
         args = [self.bridge.jsonStringify(startPos),self.bridge.jsonStringify(endPos)]
         command = self.createCommand(StateOperations.LTRIM,list,args)
         response = await self.executeCommand(command)
-        return self.bridge.jsonParse(response)
+        return response
     
     async def linsert(self,list,before,pivot,value):
         direction = "AFTER"
@@ -165,7 +184,7 @@ class State(IState):
         args = [direction,self.bridge.jsonStringify(pivot),self.bridge.jsonStringify(value)]
         command = self.createCommand(StateOperations.LINSERT,list,args)
         response = await self.executeCommand(command)
-        return self.bridge.jsonParse(response)
+        return response
     
     async def lindex(self,list,position):
         args = [self.bridge.jsonStringify(position)]
@@ -178,18 +197,26 @@ class State(IState):
         command = self.createCommand(StateOperations.LSET,list,args)
         return await self.executeCommand(command)
     
-    async def incrby(self,key,count):
-        args = [self.bridge.jsonStringify(count)]
+    async def incrby(self,key,value):
+        args = [self.bridge.jsonStringify(value)]
         command = self.createCommand(StateOperations.INCRBY,key,args)
         response = await self.executeCommand(command)
         return self.bridge.jsonParse(response)
     
-    async def decrby(self,key,count):
-        args = [self.bridge.jsonStringify(count)]
+    async def decrby(self,key,value):
+        args = [self.bridge.jsonStringify(value)]
         command = self.createCommand(StateOperations.DECRBY,key,args)
         response = await self.executeCommand(command)
         return self.bridge.jsonParse(response)
     
+    async def expire(self,key,seconds,option = None):
+        args = [self.bridge.jsonStringify(seconds)]
+        if option is not None:
+            args.append(option)
+        
+        command = self.createCommand(StateOperations.EXPIRE,key,args)
+        return await self.executeCommand(command)
+    
     def parseResponse(self,response):
         result = []
         if response is not None:
