@@ -27,3 +27,7 @@ class StateOperations:
     INCRBY = "INCRBY"
     DECRBY = "DECRBY"
     RPOP = "RPOP"
+    EXPIRE = "EXPIRE"
+    HLEN = "HLEN"
+    HINCRBY = "HINCRBY"
+    HSCAN = "HSCAN"
