@@ -10,6 +10,7 @@ from nerualpha.providers.voice.conversation import Conversation
 from nerualpha.providers.voice.contracts.IVapiEventParams import IVapiEventParams
 from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 from nerualpha.providers.voice.contracts.vapiCreateCallResponse import VapiCreateCallResponse
+from nerualpha.providers.voice.contracts.IVapiCreateCallOptions import IVapiCreateCallOptions
 
 
 #interface
@@ -27,7 +28,7 @@ class IVoice(ABC):
     def onVapiEvent(self,params):
         pass
     @abstractmethod
-    def vapiCreateCall(self,from_,to,ncco):
+    def vapiCreateCall(self,from_,to,ncco,options = None):
         pass
     @abstractmethod
     def uploadNCCO(self,uuid,ncco):
@@ -35,3 +36,9 @@ class IVoice(ABC):
     @abstractmethod
     def getConversation(self,id):
         pass
+    @abstractmethod
+    def getCallRecording(self,recordingUrl):
+        pass
+    @abstractmethod
+    def uploadCallRecording(self,recordingUrl,assetsPath):
+        pass
