@@ -2,7 +2,8 @@ from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.services.config.urlObject import UrlObject
+from nerualpha.services.config.IUrlObject import IUrlObject
+from nerualpha.request.responseTypes import ResponseTypes
 
 T = TypeVar("T")
 
@@ -10,6 +11,7 @@ T = TypeVar("T")
 #interface
 class IRequestParams(ABC,Generic[T]):
     method:str
-    url:UrlObject
+    url:IUrlObject
     data:T
     headers:Dict[str,str]
+    responseType:ResponseTypes
