@@ -3,16 +3,18 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.request.IRequestParams import IRequestParams
-from nerualpha.services.config.urlObject import UrlObject
+from nerualpha.services.config.IUrlObject import IUrlObject
+from nerualpha.request.responseTypes import ResponseTypes
 
 T = TypeVar("T")
 
 @dataclass
 class RequestParams(IRequestParams,Generic[T]):
-    url: UrlObject
+    url: IUrlObject
     method: str
     data: T = None
     headers: Dict[str,str] = None
+    responseType: ResponseTypes = None
     def __init__(self):
         pass
     def reprJSON(self):
