@@ -2,9 +2,10 @@ from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
+from nerualpha.services.config.IUrlObject import IUrlObject
 
 @dataclass
-class UrlObject:
+class UrlObject(IUrlObject):
     query: Dict[str,str]
     host: str
     pathname: str = None
