@@ -2,10 +2,13 @@ from dataclasses import dataclass, field, asdict
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.services.jwt.jwtPayload import JWTPayload
 from nerualpha.IBridge import IBridge
 from nerualpha.services.config.IConfig import IConfig
 from nerualpha.services.jwt.IJwt import IJWT
+from nerualpha.services.jwt.acl import Acl
+from nerualpha.services.jwt.ICreateVonageTokenParams import ICreateVonageTokenParams
+from nerualpha.services.jwt.neruJWTPayload import NeruJWTPayload
+from nerualpha.services.jwt.vonageJWTPayload import VonageJWTPayload
 
 @dataclass
 class JWT(IJWT):
@@ -21,12 +24,12 @@ class JWT(IJWT):
         try:
             if self._token is None or self.isExpired():
                 exp = self.bridge.getSystemTime() + self.ttl
-                self._token = self.mintToken(exp)
+                self._token = self.createNeruToken(exp)
             
             return self._token
         
         except Exception as e:
-            raise Exception("Error verifying JWT: " + e)
+            raise Exception("Error during jwt generation:" + e)
         
     
     def isExpired(self):
@@ -35,15 +38,28 @@ class JWT(IJWT):
         payload = self.bridge.jwtDecode(self._token)
         return payload["exp"] - twentySeconds <= nowInSeconds
     
-    def mintToken(self,exp):
-        now = self.bridge.getSystemTime()
-        payload = JWTPayload()
-        payload.api_account_id = self.config.apiAccountId
-        payload.api_application_id = self.config.apiApplicationId
-        payload.sub = self.config.instanceServiceName
-        payload.iat = now
-        payload.exp = exp
-        return self.bridge.jwtSign(payload,self.config.privateKey,"RS256")
+    def createNeruToken(self,exp):
+        p = NeruJWTPayload()
+        p.api_application_id = self.config.apiApplicationId
+        p.api_account_id = self.config.apiAccountId
+        p.exp = exp
+        p.sub = self.config.instanceServiceName
+        return self.bridge.jwtSign(p,self.config.privateKey,"RS256")
+    
+    def createVonageToken(self,params):
+        jwtPayload = VonageJWTPayload()
+        jwtPayload.iat = self.bridge.getSystemTime()
+        jwtPayload.exp = params.exp
+        jwtPayload.application_id = self.config.apiApplicationId
+        jwtPayload.jti = self.bridge.uuid()
+        if params.aclPaths:
+            jwtPayload.acl = Acl()
+            jwtPayload.acl.paths = params.aclPaths
+        
+        if params.subject:
+            jwtPayload.sub = params.subject
+        
+        return self.bridge.jwtSign(jwtPayload,self.config.privateKey,"RS256")
     
     def reprJSON(self):
         result = {}
